==> haskell-abstract-deque-0.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-2zsgznXQNzOK40bsGEQM3E
key: abstract-deque-0.3-2zsgznXQNzOK40bsGEQM3E
license: BSD3
maintainer: rrnewton@gmail.com
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
author: Ryan R. Newton
exposed: True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
    Data.Concurrent.Deque.Debugger
abi: cce59bf951e5f5e0080c8060202709bf
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-2zsgznXQNzOK40bsGEQM3E
depends:
    array-0.5.1.1 base-4.9.1.0 containers-0.5.7.1
    random-1.1-9tceXaeYIMZ4JrKq20Egog time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-deque-0.3-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-GrgiPXB2fbbKYfNSIYfZyO
key: abstract-deque-0.3-GrgiPXB2fbbKYfNSIYfZyO
license: BSD3
maintainer: rrnewton@gmail.com
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
author: Ryan R. Newton
exposed: True
indefinite: False
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
abi: 80c9b22623e37d94a6b111ffb49f85e4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-GrgiPXB2fbbKYfNSIYfZyO
depends:
    base-4.10.0.0 array-0.5.2.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    containers-0.5.10.2 time-1.8.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             array-0.5.2.0=044554210403f250e868a2183de060a9
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
